<?php

declare(strict_types=1);

namespace App\Service\DrinkType;

use App\Entity\DrinkType;
use App\Entity\PropertyChangeLog;
use Doctrine\ORM\EntityManagerInterface;
use Doctrine\ORM\Events;

final class DrinkTypeUpdateLog
{
    public function handleLog(string $action, DrinkType $entity, EntityManagerInterface $em): void
    {
        match ($action) {
            Events::postPersist => $this->handleCreate($entity, $em),
            Events::postUpdate => $this->handleUpdate($entity, $em),
        };
    }

    private function handleCreate(DrinkType $entity, EntityManagerInterface $em): void
    {
        $this->logWanted($entity, $em);
        $this->logCurrent($entity, $em);
    }

    private function logWanted(DrinkType $entity, EntityManagerInterface $em): void
    {
        $logWanted = new PropertyChangeLog();
        $logWanted->setNewValue((string) $entity->getWantedStock());
        $logWanted->setEntityClass(DrinkType::class);
        $logWanted->setEntityId($entity->getId());
        $logWanted->setPropertyName('wantedStock');

        $em->persist($logWanted);
        $em->flush();
    }

    private function logCurrent(DrinkType $entity, EntityManagerInterface $em): void
    {
        $logCurrent = new PropertyChangeLog();
        $logCurrent->setNewValue((string) $entity->getCurrentStock());
        $logCurrent->setEntityClass(DrinkType::class);
        $logCurrent->setEntityId($entity->getId());
        $logCurrent->setPropertyName('currentStock');

        $em->persist($logCurrent);
        $em->flush();
    }

    private function handleUpdate(DrinkType $entity, EntityManagerInterface $em): void
    {
        $uow = $em->getUnitOfWork();
        $changeSet = $uow->getEntityChangeSet($entity);
        if (isset($changeSet['wantedStock'])) {
            $this->logWanted($entity, $em);
        }
        if (isset($changeSet['currentStock'])) {
            $this->logCurrent($entity, $em);
        }
    }
}
